@@ -1,13 +1,13 @@
 #ifndef DOWNLOADMANAGER_H
 #define DOWNLOADMANAGER_H
-
 #include <QObject>
 #include <QtNetwork/QNetworkAccessManager>
 #include <QUrl>
 #include <QFile>
-#include <QDir>
 #include <QList>
 #include <QTime>
+#include <QVariantMap>
+#include <QProcess>
 
 class QNetworkAccessManager;
 class QNetworkReply;
@@ -29,42 +29,55 @@ public:
 signals:
 
 public slots:
-    void setDownloadQuality(const QString &quality);
-    void startDownload(const QString &filePath, const QString &url);
+    void setYouTubeDownloadQuality(const QString &quality);
+    void setDownloadPath(const QString &path);
+    void startDownload(const QVariantMap &video);
     void pauseDownload();
     void cancelDownload();
+    void deleteIncompleteDownload(QString title);
 
 private slots:
-    void parseVideoPage(QNetworkReply *reply);
-    void parseDMVideoPage();
-    void parseVimeoVideoPage();
-    void getVideoUrl(const QString &playerUrl);
-    void getDMVideoUrl(const QString &link);
-    void getVimeoVideoUrl(const QString &link);
+    void parseYouTubeVideoPage(QNetworkReply *reply);
+    void parseDailymotionVideoPage();
+    void getYouTubeVideoUrl(const QString &videoId);
+    void getDailymotionVideoUrl(const QString &videoId);
     void performDownload(const QUrl &videoUrl);
+    void updateSize();
     void updateProgress(qint64 bytesReceived, qint64 bytesTotal);
     void downloadFinished();
     void downloadReadyRead();
     void setIsDownloading(const bool isDownloading) { downloading = isDownloading; emit downloadingChanged(); }
+    void downloadThumbnail();
+    void thumbnailDownloadFinished();
+    void convertToAudio();
+    void conversionFinished(int exitCode, QProcess::ExitStatus exitStatus);
 
 private:
     QNetworkAccessManager *nam;
     int downloadFormat;
     QHash<QString, int> dlMap;
     QFile output;
+    bool downloading;
     QNetworkReply *downloadReply;
     QTime downloadTime;
-    bool downloading;
+    QString downloadPath;
+    QVariantMap videoToDownload;
+    QProcess *converter;
 
 signals:
     void alert(const QString &message);
     void gotVideoUrl(const QUrl &videoUrl);
-    void downloadCompleted(const QString &filename);
+    void downloadCompleted();
+    void downloadStarted();
     void downloadCancelled();
+    void downloadPaused();
+    void downloadResumed();
+    void downloadFailed(const QString &reason);
     void statusChanged(const QString &status);
-    void progressChanged(qint64 bytesReceived, qint64 bytesTotal, const QString &speed);
-    void qualityChanged(const QString quality);
+    void progressChanged(float progress, int eta);
+    void sizeChanged(qint64 size);
     void downloadingChanged();
+    void conversionStarted();
 };
 
 #endif // DOWNLOADMANAGER_H
